@@ -24,13 +24,13 @@
 # delete this exception statement from your version.
 
 from gnomemusic.player import PlaybackStatus, RepeatType
-from gnomemusic.albumArtCache import AlbumArtCache
+from gnomemusic.albumartcache import AlbumArtCache
 from gnomemusic.grilo import grilo
 from gnomemusic.playlists import Playlists
+import gnomemusic.utils as utils
 
 from gettext import gettext as _
 from gi.repository import GLib
-from gi.repository import Grl
 from gi.repository import Gio
 from gnomemusic import log
 import logging
@@ -309,29 +309,16 @@ class MediaPlayer2Service(Server):
             assert album is not None
         except:
             try:
-                album = media.get_string(Grl.METADATA_KEY_ALBUM)
+                album = media.get_album()
                 assert album is not None
             except:
                 album = _("Unknown Album")
         finally:
             metadata['xesam:album'] = GLib.Variant('s', album)
 
-        try:
-            artist = media.get_artist()
-            assert artist is not None
-        except:
-            try:
-                artist = media.get_string(Grl.METADATA_KEY_ARTIST)
-                assert artist is not None
-            except:
-                try:
-                    artist = media.get_author()
-                    assert artist is not None
-                except (AssertionError, ValueError):
-                    artist = _("Unknown Artist")
-        finally:
-            metadata['xesam:artist'] = GLib.Variant('as', [artist])
-            metadata['xesam:albumArtist'] = GLib.Variant('as', [artist])
+        artist = utils.get_artist_name(media)
+        metadata['xesam:artist'] = GLib.Variant('as', [artist])
+        metadata['xesam:albumArtist'] = GLib.Variant('as', [artist])
 
         try:
             genre = media.get_genre()
@@ -748,10 +735,10 @@ class MediaPlayer2Service(Server):
                 elif new_value == 'Playlist':
                     self.player.set_repeat_mode(RepeatType.ALL)
             elif property_name == 'Shuffle':
-                if (new_value and self.player.get_repeat_mode() != RepeatType.SHUFFLE):
-                    self.set_repeat_mode(RepeatType.SHUFFLE)
-                elif new_value and self.player.get_repeat_mode() == RepeatType.SHUFFLE:
-                    self.set_repeat_mode(RepeatType.NONE)
+                if new_value:
+                    self.player.set_repeat_mode(RepeatType.SHUFFLE)
+                else:
+                    self.player.set_repeat_mode(RepeatType.NONE)
         else:
             raise Exception(
                 'org.mpris.MediaPlayer2.GnomeMusic',
